summaryrefslogtreecommitdiffstatshomepage
path: root/src/emu
diff options
context:
space:
mode:
author Olivier Galibert <galibert@pobox.com>2021-05-12 11:00:58 +0200
committer Olivier Galibert <galibert@pobox.com>2021-05-12 11:01:06 +0200
commitba8320a3014ae78f299316c74ce98582a1dcd80b (patch)
tree5c2202b8c8e133638aa58bcedbe83d467f4a42ba /src/emu
parenta1f41c8e08b678d5a0ec9e7cb057e0f4acb136c4 (diff)
mview: Fix missing import of submaps in views. Need to fix more about import_submap vs. prepare_map vs. populate_from_map though.
Diffstat (limited to 'src/emu')
-rw-r--r--src/emu/emumem_mview.cpp6
1 files changed, 4 insertions, 2 deletions
diff --git a/src/emu/emumem_mview.cpp b/src/emu/emumem_mview.cpp
index 83280460cc7..d6750ad2e23 100644
--- a/src/emu/emumem_mview.cpp
+++ b/src/emu/emumem_mview.cpp
@@ -609,9 +609,11 @@ void memory_view::memory_view_entry::prepare_device_map(address_map &map)
template<int Level, int Width, int AddrShift, endianness_t Endian> void memory_view_entry_specific<Level, Width, AddrShift, Endian>::populate_from_map(address_map *map)
{
- // no map specified, use the space-specific one
- if (map == nullptr)
+ // no map specified, use the space-specific one and import the submaps
+ if (map == nullptr) {
map = m_map.get();
+ map->import_submaps(m_manager.machine(), m_view.m_device, data_width(), endianness(), addr_shift());
+ }
prepare_map_generic(*map, true);